==> haskell-string-interpolate-0.3.4.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-interpolate
version:              0.3.4.0
visibility:           public
id:                   string-interpolate-0.3.4.0-5Ws3COJGwR537UBRNVUzaR
key:                  string-interpolate-0.3.4.0-5Ws3COJGwR537UBRNVUzaR
license:              BSD-3-Clause
copyright:            2019-2024 William Yao
maintainer:           williamyaoh@gmail.com
author:               William Yao
homepage:
    https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md

synopsis:
    Haskell string/text/bytestring interpolation that just works

description:
    Unicode-aware string interpolation that handles all textual types.

    See the README at <https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md> for more info.

category:             Data, Text
abi:                  51f172d4f776f9265d367329a4e11c50
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.Conversion
    Data.String.Interpolate.Conversion.ByteStringSink
    Data.String.Interpolate.Conversion.TextSink
    Data.String.Interpolate.Parse Data.String.Interpolate.Types

hidden-modules:
    Data.String.Interpolate.Conversion.Classes
    Data.String.Interpolate.Conversion.Encoding
    Data.String.Interpolate.Lines Data.String.Interpolate.Whitespace
    Paths_string_interpolate

import-dirs:          /usr/lib/ghc-9.2.8/site-local/string-interpolate-0.3.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/string-interpolate-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-interpolate
hs-libraries:         HSstring-interpolate-0.3.4.0-5Ws3COJGwR537UBRNVUzaR
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    haskell-src-exts-1.23.1-HUqC9Egs1QYJTMY2psL17i
    haskell-src-meta-0.8.13-K82q3ORY4nEGdZM6mpdQHq
    split-0.2.5-D8Q5hs7UAOeFSfUt4jgpO4 template-haskell-2.18.0.0
    text-1.2.5.0 text-conversions-0.3.1.1-CN2l1t2OoVw9WKRq3aPEkG
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI

haddock-interfaces:
    /usr/share/doc/haskell-string-interpolate/html/string-interpolate.haddock

haddock-html:         /usr/share/doc/haskell-string-interpolate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-interpolate-0.3.4.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-interpolate
version:              0.3.4.0
visibility:           public
id:                   string-interpolate-0.3.4.0-Aesh2yn18mKAzk77VJOf7W
key:                  string-interpolate-0.3.4.0-Aesh2yn18mKAzk77VJOf7W
license:              BSD-3-Clause
copyright:            2019-2024 William Yao
maintainer:           williamyaoh@gmail.com
author:               William Yao
homepage:
    https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md

synopsis:
    Haskell string/text/bytestring interpolation that just works

description:
    Unicode-aware string interpolation that handles all textual types.

    See the README at <https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md> for more info.

category:             Data, Text
abi:                  91fae020e476ea0948d3ee2a14d50253
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.Conversion
    Data.String.Interpolate.Conversion.ByteStringSink
    Data.String.Interpolate.Conversion.TextSink
    Data.String.Interpolate.Parse Data.String.Interpolate.Types

hidden-modules:
    Data.String.Interpolate.Conversion.Classes
    Data.String.Interpolate.Conversion.Encoding
    Data.String.Interpolate.Lines Data.String.Interpolate.Whitespace
    Paths_string_interpolate

import-dirs:          /usr/lib/ghc-9.2.8/site-local/string-interpolate-0.3.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/string-interpolate-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-interpolate
hs-libraries:         HSstring-interpolate-0.3.4.0-Aesh2yn18mKAzk77VJOf7W
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    haskell-src-exts-1.23.1-5wKcEPhCYtCDMpJskTRGU9
    haskell-src-meta-0.8.13-Ew1QhAwhs9OBZ9NzShfghT
    split-0.2.5-Gzu4NbNnTUj6rs5DfMztSh template-haskell-2.18.0.0
    text-1.2.5.0 text-conversions-0.3.1.1-KTkZnK03aCBDd0p7LfseId
    utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX

haddock-interfaces:
    /usr/share/doc/haskell-string-interpolate/html/string-interpolate.haddock

haddock-html:         /usr/share/doc/haskell-string-interpolate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
